==> chromium-54.0.2840.25.tar.xz: chromium-54.0.2840.25/chrome/browser/dom_distiller/profile_utils.cc <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/dom_distiller/profile_utils.h"

#include <memory>
#include <utility>

#include "base/command_line.h"
#include "chrome/browser/dom_distiller/dom_distiller_service_factory.h"
#include "chrome/browser/dom_distiller/lazy_dom_distiller_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/common/chrome_isolated_world_ids.h"
#include "chrome/common/chrome_switches.h"
#include "chrome/common/features.h"
#include "components/dom_distiller/content/browser/distiller_javascript_utils.h"
#include "components/dom_distiller/content/browser/distiller_ui_handle.h"
#include "components/dom_distiller/content/browser/dom_distiller_viewer_source.h"
#include "components/dom_distiller/core/dom_distiller_switches.h"
#include "components/dom_distiller/core/url_constants.h"

#if BUILDFLAG(ANDROID_JAVA_UI)
#include "chrome/browser/android/dom_distiller/distiller_ui_handle_android.h"
#endif  // BUILDFLAG(ANDROID_JAVA_UI)

namespace dom_distiller {

void RegisterViewerSource(Profile* profile) {
  bool enabled_distiller = base::CommandLine::ForCurrentProcess()->HasSwitch(
      switches::kEnableDomDistiller);
  if (!enabled_distiller)
    return;

  DomDistillerServiceFactory* dom_distiller_service_factory =
      DomDistillerServiceFactory::GetInstance();
  // The LazyDomDistillerService deletes itself when the profile is destroyed.
  LazyDomDistillerService* lazy_service =
      new LazyDomDistillerService(profile, dom_distiller_service_factory);
  std::unique_ptr<DistillerUIHandle> ui_handle;

#if BUILDFLAG(ANDROID_JAVA_UI)
  ui_handle.reset(new dom_distiller::android::DistillerUIHandleAndroid());
#endif  // BUILDFLAG(ANDROID_JAVA_UI)

  // Set the JavaScript world ID.
  if (!DistillerJavaScriptWorldIdIsSet()) {
    SetDistillerJavaScriptWorldId(chrome::ISOLATED_WORLD_ID_CHROME_INTERNAL);
  }

  content::URLDataSource::Add(
      profile, new DomDistillerViewerSource(lazy_service, kDomDistillerScheme,
                                            std::move(ui_handle)));
}

}  // namespace dom_distiller

==> chromium_78.0.3904.97.orig.tar.xz: chromium-78.0.3904.97/chrome/browser/dom_distiller/profile_utils.cc <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/dom_distiller/profile_utils.h"

#include <memory>
#include <utility>

#include "base/command_line.h"
#include "chrome/browser/dom_distiller/dom_distiller_service_factory.h"
#include "chrome/browser/dom_distiller/lazy_dom_distiller_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/common/chrome_isolated_world_ids.h"
#include "chrome/common/chrome_switches.h"
#include "components/dom_distiller/content/browser/distiller_javascript_utils.h"
#include "components/dom_distiller/content/browser/distiller_ui_handle.h"
#include "components/dom_distiller/content/browser/dom_distiller_viewer_source.h"
#include "components/dom_distiller/core/dom_distiller_features.h"
#include "components/dom_distiller/core/url_constants.h"

#if defined(OS_ANDROID)
#include "chrome/browser/android/dom_distiller/distiller_ui_handle_android.h"
#endif  // defined(OS_ANDROID)

namespace dom_distiller {

void RegisterViewerSource(Profile* profile) {
  if (!dom_distiller::IsDomDistillerEnabled())
    return;

  DomDistillerServiceFactory* dom_distiller_service_factory =
      DomDistillerServiceFactory::GetInstance();
  // The LazyDomDistillerService deletes itself when the profile is destroyed.
  LazyDomDistillerService* lazy_service =
      new LazyDomDistillerService(profile, dom_distiller_service_factory);
  std::unique_ptr<DistillerUIHandle> ui_handle;

#if defined(OS_ANDROID)
  ui_handle =
      std::make_unique<dom_distiller::android::DistillerUIHandleAndroid>();
#endif  // defined(OS_ANDROID)

  // Set the JavaScript world ID.
  if (!DistillerJavaScriptWorldIdIsSet())
    SetDistillerJavaScriptWorldId(ISOLATED_WORLD_ID_CHROME_INTERNAL);

  content::URLDataSource::Add(
      profile, std::make_unique<DomDistillerViewerSource>(
                   lazy_service, kDomDistillerScheme, std::move(ui_handle)));
}

}  // namespace dom_distiller
